<?php
session_start();
ini_set('display_errors', '1');
ini_set('display_startup_errors', '1');
error_reporting(E_ALL);

// Define the path to the config.json file
$configFilePath = 'config.json';

// Check if the config.json file exists and is readable
if (file_exists($configFilePath) && is_readable($configFilePath)) {
    // Read the existing configuration
    $existingConfigContent = file_get_contents($configFilePath);
    $existingConfig = json_decode($existingConfigContent, true);

    // Check if json_decode was successful
    if ($existingConfig === null || $existingConfig === false) {
        // Handle the error, e.g., log it or set $existingConfig to an empty array
        error_log('Failed to decode JSON from config.json');
        $existingConfig = array();
    }
} else {
    // If the file doesn't exist or isn't readable, start with an empty array
    $existingConfig = array();
}

// Check if form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Initialize an empty array to store new config data
    $newConfigData = array();

    // Get the values from the form inputs
    $telegramBotToken = isset($_POST['telegramBotToken']) ? $_POST['telegramBotToken'] : '';
    $telegramChatId = isset($_POST['telegramChatId']) ? $_POST['telegramChatId'] : '';

    // Add the values to the $newConfigData array
    $newConfigData['telegramBotToken'] = $telegramBotToken;
    $newConfigData['telegramChatId'] = $telegramChatId;

    // Merge the existing configuration with the new data
    $mergedConfigData = array_merge($existingConfig, $newConfigData);

    // Convert the merged data to JSON format
    $jsonData = json_encode($mergedConfigData, JSON_PRETTY_PRINT);

    // Save the JSON data to the config.json file
    file_put_contents($configFilePath, $jsonData);

    // Set a session variable to indicate success
    $_SESSION['config_success'] = true;

    // Redirect back to the form page without the status query parameter
    header("Location: index.php");
    exit;
}
?>

<!-- The rest of the code remains the same -->

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Template Configuration</title>
    <!-- Bootstrap CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <style>
       .centered-container {
            background-color: #f8f9fa;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }
       .custom-form {
            background-color: #fff;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
            max-width: 500px; /* Adjust the max-width as needed */
            width: 100%;
        }
       .btn-fill-width {
            width: 100%;
        } 
        .inputcustom {
            width: 1em;
            height: 1em;
            margin-top: .25em;
            vertical-align: top;
            background-color: #fff;
            background-repeat: no-repeat;
            background-position: center;
            background-size: contain;
            border: 1px solid rgba(0,0,0,.25); 
        }
    </style>
</head>

<body>
    <div class="centered-container">
        <div class="custom-form">
            <h2 class="mb-4 text-left">Telegram Config</h2>
            <?php if (isset($_SESSION['config_success']) && $_SESSION['config_success']):?>
                <div class="alert alert-success" role="alert">
                    Configuration saved successfully!
                </div>
                <?php unset($_SESSION['config_success']);?>
            <?php endif;?> 
            <form action="index.php" method="post">
                <div class="form-group"> 
                    <label for="telegramBotToken">Telegram Bot Token:</label> 
                    <input type="text" class="form-control" id="telegramBotToken" name="telegramBotToken">
                </div>
                <div class="form-group">
                    <label for="telegramChatId">Telegram Chat ID:</label>
                    <input type="text" class="form-control" id="telegramChatId" name="telegramChatId">
                </div>
                <button type="submit" class="btn btn-primary btn-fill-width">Save Configuration</button>
                <a href="../index.php" class="btn btn-fill-width" style="margin-top: 15px; color: #007bff!important;">Go Back</a>
            </form>
        </div>
    </div>

    <!-- Include jQuery first -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Then include Bootstrap's JavaScript -->
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script>
        // Function to hide the success message after 3 seconds
        function hideSuccessMessage() {
            var successMessage = document.querySelector('.alert-success');
            if (successMessage) {
                setTimeout(function () {
                    successMessage.style.display = 'none';
                    // Redirect back to the form page after hiding the message
                    window.location.href = 'index.php';
                }, 3000); // 3000 milliseconds = 3 seconds
            }
        }

        // Call the function when the page loads
        window.onload = hideSuccessMessage;
    </script> 
</body>

</html>




