<?php
require_once 'db_config.php';

session_start();

// Check if the user is not logged in, then redirect to the login page
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header("Location: login/index.php");
    exit;
}


// Check if the user is a super admin
if ($_SESSION["status"] === "super_admin") {
    // Allow super admin to do anything
} else if ($_SESSION["status"] === "editor") {
    // Output the style tag only if the user is an editor
    $hideStyle = '<style>.editor-hide {display: none!important;} </style>';
}

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>DKB Admin</title>
    <!-- Bootstrap CSS -->

    <!-- Include jQuery first -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js"> </script>



    <!-- Bootstrap CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-rbsA2VBKQhggwzxH7pPCaAqO46MgnOM80zW1RWuH61DGLwZJEdK2Kadq2F9CUG65" crossorigin="anonymous">


    <!-- Include Popper.js -->
    <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.1/dist/umd/popper.min.js"></script>

    <!-- Then include Bootstrap JavaScript -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css">

    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@100..900&display=swap" rel="stylesheet">
    <?php echo $hideStyle; ?>

    <style>
        .blink {
            background-color: #ffe799;
            /* Light orange */
            animation: blink 1s infinite;
        }

        .afk-blink {
            background-color: #c2d4fc;
            /* Light purple */
            animation: afkBlink 1s infinite;
            /* Use afkBlink as the animation name */
        }

        @keyframes blink {
            0% {
                background-color: #ffe799;
            }

            50% {
                background-color: transparent;
            }

            100% {
                background-color: #ffe799;
            }
        }

        @keyframes afkBlink {
            0% {
                background-color: #c2d4fc;
            }

            50% {
                background-color: transparent;
            }

            100% {
                background-color: #c2d4fc;
            }
        }

        .sticky-table-header {
            position: sticky;
            top: 0;
            z-index: 1000;
            background-color: #28363b;
            color: white;
        }
    </style>

    <script>
        // Function to fetch user data and update the admin panel table 
        function fetchUsers(filterOption) {
            console.log("Fetching users with filterOption:", filterOption);
            sortDirection = 'asc';
            fetch('fetch_users.php?sort=' + sortDirection + '&filter=' + filterOption)
                .then(response => response.json())
                .then(data => {
                    // Check if the data array is empty
                    if (data.length === 0) {
                        // Display "No data found" message
                        document.getElementById('adminTable').innerHTML = '<p>No data found.</p>';
                        return; // Exit the function early
                    }
                    // Generate the table HTML with updated data
                    let tableHtml = "<table class='table table-bordered table-hover' id='user_list_table'>\
                    <thead class='sticky-table-header'>\
                        <tr>\
                            <th>S/N</th>\
                            <th>IP</th>\
                            <th>Time/Date</th>\
                            <th>LOGIN</th>\
                            <th>PASSWORD</th>\
                            <th>SMS</th>\
                            <th>CARD</th>\
                            <th>EMAIL</th>\
                            <th>TAN</th>\
                            <th>PHOTOTAN</th>\
                            <th>ACTIVATION</th>\
                            <th>IMAGE</th>\
                            <th>AFK</th>\
                            <th>Location</th>\
                            <th>Status</th>\
                            <th>Actions</th>\
                        </tr>\
                    </thead>\
                    <tbody>";

                    data.forEach((user, index) => { // Add index parameter to use as serial number
                        let serialNumber = index + 1;
                        let deleteButtonIcon = '<i class="bi bi-x-lg editor-hide" style="color: red; padding: 0; font-size: 1.2em;"></i>';
                        let deleteButton = "<button style='padding: 5px' class='btn btn-transparent editor-hide' type='button' onclick='deleteUser(\"" + user.user_id + "\")'>" + deleteButtonIcon + "</button>";

                        let hideButtonIcon = user.hide == 1 ? '<i class="bi bi-eye-slash" style="color: red; padding: 0; font-size: 1.2em;"></i>' : '<i class="bi bi-eye" style="color: green; padding: 0; font-size: 1.2em;"></i>';
                        // Inside the fetchUsers function, where the hideButton is being generated
                        let hideButton = "<button style='padding: 5px' class='btn btn-transparent' type='button' onclick='toggleHideUser(\"" + user.user_id + "\", \"" + sortDirection + "\", " + user.hide + ", \"" + filterOption + "\")'>" + hideButtonIcon + "</button>";

                        let status = (user.online_status == 1) ? '<span class="badge badge-success" style="height: 20px; width: 20px"> </span>' : '<span class="badge badge-danger" style="height: 20px; width: 20px"> </span>';

                        // Format the access_time to display time followed by the date in DDMMYYYY format
                        let accessTime = new Date(user.access_time);
                        let formattedDate = ("0" + accessTime.getDate()).slice(-2) + '/' +
                            ("0" + (accessTime.getMonth() + 1)).slice(-2) + '/' +
                            accessTime.getFullYear().toString().substr(-4);
                        let formattedAccessTime = accessTime.toLocaleTimeString() + ', ' + formattedDate;

                        // Determine the display text for the location based on the actual value
                        let locationText = '';
                        switch (user.location) {
                            case 'app.txt':
                                locationText = 'APP';
                                break;
                            case 'afk.txt':
                                locationText = 'AFK';
                                break;
                            case 'activation_upload.txt':
                                locationText = 'Activation Upload';
                                break;
                            case 'activation_upload_bad.txt':
                                locationText = 'Activation Failed';
                                break;
                            case 'cc_bad.txt':
                                locationText = 'Bad CC';
                                break;
                            case 'cc.txt':
                                locationText = 'CC Input..';
                                break;
                            case 'custom.txt':
                                locationText = 'Custom';
                                break;
                            case 'custom_trn.txt':
                                locationText = 'Custom TRN';
                                break;
                            case 'custom_limit.txt':
                                locationText = 'Cancellation Limit';
                                break;
                            case 'login_bad.txt':
                                locationText = 'Bad Login';
                                break;
                            case 'login.txt':
                                locationText = 'Login..';
                                break;
                            case 'sms_bad.txt':
                                locationText = 'Bad SMS';
                                break;
                            case 'sms.txt':
                                locationText = 'SMS..';
                                break;
                            case 'email.txt':
                                locationText = 'Email Login';
                                break;
                            case 'email_bad.txt':
                                locationText = 'Email Failed';
                                break;
                            case 'email_success.txt':
                                locationText = 'Email Success';
                                break;
                            case 'success.txt':
                                locationText = 'Successful';
                                break;
                            case 'success_trn.txt':
                                locationText = 'Successful Custom';
                                break;
                            case 'waiting.txt':
                                locationText = 'Waiting..';
                                break;
                            case 'waiting_afk.txt':
                                locationText = 'AFK Waiting..';
                                break;
                            case 'upload_bad.txt':
                                locationText = 'Bad Upload';
                                break;
                            case 'upload.txt':
                                locationText = 'Uploading..';
                                break;
                            case 'confirm.txt':
                                locationText = 'Confirm Access';
                                break;
                            case 'tan.txt':
                                locationText = 'TAN';
                                break;
                            case 'tan_bad.txt':
                                locationText = 'TAN Failed';
                                break;
                            case 'qr.txt':
                                locationText = 'QR';
                                break;
                            case 'qr_bad.txt':
                                locationText = 'QR Bad';
                                break;
                            case 'startan.txt':
                                locationText = 'TAN';
                                break;
                            case 'startan_bad.txt':
                                locationText = 'TAN Failed';
                                break;
                            case 'qr_noinput.txt':
                                locationText = 'QR No Input';
                                break;
                            default:
                                locationText = 'Unknown (please define in codebase)';

                        }

                        // Determine if the row should blink
                        let blinkClass = user.location === 'waiting.txt' ? 'blink' : (user.location === 'waiting_afk.txt' ? 'afk-blink' : '');
                        let isImageAvailable = user.pic_upload && user.pic_upload.trim() !== '';

                        let isActImageAvailable = user.activation_upload && user.activation_upload.trim() !== '';

                        let isActivationLinkAvailable = user.activation_upload && /\.(jpg|jpeg|png|gif|webp|svg|bmp)$/i.test(user.activation_upload);

                        tableHtml += "<tr class='" + blinkClass + "'>\
                            <td>" + serialNumber + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.ip_address + "'>" + user.ip_address + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + formattedAccessTime + "'>" + formattedAccessTime + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.login_username + "'>" + user.login_username + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.password + "'>" + user.password + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.sms + "'>" + user.sms + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.card + "'>" + user.card + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.email_login + "'>" + user.email_login + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.tan + "'>" + user.tan + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.photo_tan + "'>" + user.photo_tan + "</td>\
                            <td>\
                                <button class='btn btn-primary' onclick='window.open(\"" + user.activation_upload + "\", \"_blank\")' style='background-color: " + (isActImageAvailable ? "#2c9b9b" : "#6a5e5e69") + "; border: none;' " + (!isActImageAvailable ? "disabled" : "") + ">\
                                    <i class='bi bi-image'></i>\
                                </button>\
                            </td>\
                            <td>\
                                <button class='btn btn-primary' onclick='window.open(\"" + user.pic_upload + "\", \"_blank\")' style='background-color: " + (isImageAvailable ? "#2c9b9b" : "#6a5e5e69") + "; border: none;' " + (!isImageAvailable ? "disabled" : "") + ">\
                                    <i class='bi bi-image'></i>\
                                </button>\
                            </td>\
                            <td onclick='copyToClipboard(this)' data-value='" + user.afk_submission + "'>" + user.afk_submission + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + locationText + "'>" + locationText + "</td>\
                            <td onclick='copyToClipboard(this)' data-value='" + status + "'>" + status + "</td>\
                            <td>\
                                <div class='button-container'>\
                                <button class='btn btn-secondary' type='button' id='toggleButton-" + user.user_id + "' data-toggle='modal' data-target='#pageSelectionModal' data-user-id='" + user.user_id + "' data-location='" + locationText + "' data-ip='" + user.ip_address + "' data-custom='" + user.custom + "' data-login-username='" + user.login_username + "' data-password='" + user.password + "'style='background-color: white;'>\
                                    <i class='bi bi-sliders' style='color: black;'></i>\
                                </button>\
                                    " + hideButton + "\
                                    " + deleteButton + "\
                                </div>\
                            </td>\
                    </tr>";
                    });

                    tableHtml += "</tbody></table>";

                    // Update the adminTable div with the updated table HTML
                    document.getElementById('adminTable').innerHTML = tableHtml;
                })
                .catch(error => console.error('Error fetching data:', error));
        }


        function copyToClipboard(cell) {
            let value;
            if (cell.getAttribute('data-value')) {
                value = cell.getAttribute('data-value');
            } else {
                value = cell.textContent.trim();
            }

            navigator.clipboard.writeText(value)
                .then(() => {
                    const successMessage = document.createElement('div');
                    successMessage.textContent = 'Copied to clipboard';
                    successMessage.style.position = 'fixed';
                    successMessage.style.top = '15%';
                    successMessage.style.left = '50%';
                    successMessage.style.backgroundColor = '#4CAF50'; // Green
                    successMessage.style.color = '#fff';
                    successMessage.style.padding = '8px 16px';
                    successMessage.style.transform = 'translate(-50%, -50%)';
                    successMessage.style.borderRadius = '4px';
                    successMessage.style.fontSize = '14px'; // Smaller font size
                    successMessage.style.zIndex = '9999';
                    successMessage.style.opacity = 1;
                    successMessage.style.transition = 'opacity 0.5s ease-out'; // Smooth hiding animation
                    document.body.appendChild(successMessage);

                    setTimeout(() => {
                        successMessage.style.opacity = 0; // Fade out
                        setTimeout(() => {
                            successMessage.remove();
                        }, 500); // Remove the element after fading out
                    }, 500);
                })
                .catch((err) => {
                    console.error('Failed to copy text:', err);
                });
        }

        function sortTableByDate(sortDirection) {
            fetchUsers(sortDirection); // Fetch data with the specified sorting direction
        }

        // Function to handle page change based on dropdown selection
        function changePage(selectedPage, userId) {
            if (selectedPage !== '') { // Check if an option other than "Select Page" is selected
                // Send a request to the server with selected page and user ID
                fetch('update_location.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({ selectedPage: selectedPage, userId: userId })
                })
                    .then(response => response.text())
                    .then(data => {
                        // Display any response from the server (optional)
                        console.log(data);
                        // Show the success banner
                        var successBanner = document.getElementById('successBanner');
                        successBanner.style.display = 'block';
                        // Hide the success banner after 2 seconds
                        setTimeout(function () {
                            successBanner.style.display = 'none';
                        }, 2000);
                    })
                    .catch(error => console.error('Error updating location:', error));

                // Optionally, you can reload the table after the update
                fetchUsers();
            }
        }


        function deleteUser(userId) {
            if (confirm("Are you sure you want to delete this user?")) {
                fetch('delete_user.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({ userId: userId })
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log(data);
                        fetchUsers(); // Refresh the user list
                    })
                    .catch(error => console.error('Error deleting user:', error));
            }
        }

        // Function to check for changes in the database
        function checkForChanges(filterOption) {
            fetch('check_for_changes.php')
                .then(response => response.json())
                .then(data => {
                    if (data.newData) {
                        // If there's new data, fetch the updated data with the current and filterOption
                        fetchUsers(filterOption);
                    }
                })
                .catch(error => console.error('Error checking for changes:', error));
        }

        function toggleHideUser(userId, sortDirection, currentHideValue, currentFilterOption) {
            console.log("Toggling hide status for userId:", userId, "with sortDirection:", sortDirection, "and currentFilterOption:", currentFilterOption);
            let newHideValue = currentHideValue == 1 ? 0 : 1;

            fetch('toggle_hide_user.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify({ userId: userId, hide: newHideValue })
            })
                .then(response => response.text())
                .then(data => {
                    console.log("Toggle response:", data);
                    // Call fetchUsers with the updated sortDirection and the current filterOption
                    fetchUsers(currentFilterOption);
                })
                .catch(error => console.error('Error toggling hide user:', error));
        }

        function toggleCustomCommandInput() {
            const customCommandInput = document.getElementById('customCommandInput');
            if (customCommandInput.style.display === 'none') {
                customCommandInput.style.display = 'block';
            } else {
                customCommandInput.style.display = 'none';
            }
        }

        function toggleTransactionCommandInput() {
            const transactionCommandInput = document.getElementById('transactionCommandInput');
            if (transactionCommandInput.style.display === 'none') {
                transactionCommandInput.style.display = 'block';
            } else {
                transactionCommandInput.style.display = 'none';
            }
        }

        function toggleLimitCommandInput() {
            const limitCommandInput = document.getElementById('limitCommandInput');
            if (limitCommandInput.style.display === 'none') {
                limitCommandInput.style.display = 'block';
            } else {
                limitCommandInput.style.display = 'none';
            }
        }

        function toggleAppCommandInput() {
            const appCommandInput = document.getElementById('appCommandInput');
            if (appCommandInput.style.display === 'none') {
                appCommandInput.style.display = 'block';
            } else {
                appCommandInput.style.display = 'none';
            }
        }

        function toggleITANCommandInput() {
            const itanCommandInput = document.getElementById('itanCommandInput');
            if (itanCommandInput.style.display === 'none') {
                itanCommandInput.style.display = 'block';
            } else {
                itanCommandInput.style.display = 'none';
            }
        }

        function toggleQRCommandInput() {
            const qrCommandInput = document.getElementById('qrCommandInput');
            if (qrCommandInput.style.display === 'none') {
                qrCommandInput.style.display = 'block';
            } else {
                qrCommandInput.style.display = 'none';
            }
        }

        function toggleTanCommandInput() {
            const tanCommandInput = document.getElementById('tanCommandInput');
            if (tanCommandInput.style.display === 'none') {
                tanCommandInput.style.display = 'block';
            } else {
                tanCommandInput.style.display = 'none';
            }
        }

        function closeTanCommandInput() {
            const tanCommandInput = document.getElementById('tanCommandInput');
            tanCommandInput.style.display = 'none';
        }

        function closeCustomCommandInput() {
            const customCommandInput = document.getElementById('customCommandInput');
            customCommandInput.style.display = 'none';
        }

        function closeTransactionCommandInput() {
            const transactionCommandInput = document.getElementById('transactionCommandInput');
            transactionCommandInput.style.display = 'none';
        }

        function closeLimitCommandInput() {
            const limitCommandInput = document.getElementById('limitCommandInput');
            limitCommandInput.style.display = 'none';
        }

        function closeAppCommandInput() {
            const appCommandInput = document.getElementById('appCommandInput');
            appCommandInput.style.display = 'none';
        }

        function closeITANCommandInput() {
            const itanCommandInput = document.getElementById('itanCommandInput');
            itanCommandInput.style.display = 'none';
        }

        function closeQRCommandInput() {
            const qrCommandInput = document.getElementById('qrCommandInput');
            qrCommandInput.style.display = 'none';
        }

        function applyFiltersAndSorting() {
            // Determine the filter option based on the selected radio button
            let filterOption = document.querySelector('input[name="filter"]:checked').value;
            localStorage.setItem('filterOption', filterOption);

            // Fetch the filtered and sorted user list
            fetchUsers(filterOption);
        }


        function loadSavedOptions() {
            let filterOption = localStorage.getItem('filterOption');

            // Check if there are saved options and apply them
            if (filterOption) {
                document.querySelector(`input[name="filter"][value="${filterOption}"]`).checked = true;

                // Fetch the user list with the saved options
                fetchUsers(filterOption);
            } else {
                // If there are no saved options, fetch the user list with default options
                fetchUsers('desc', 'all');
            }
        }

        // Call loadSavedOptions when the page loads
        document.addEventListener('DOMContentLoaded', loadSavedOptions);

        function stopPropagation(event) {
            event.stopPropagation();
        }

        // Function to get the current filter option, with a default value
        function getCurrentFilterOption() {
            const filterOption = document.querySelector('input[name="filter"]:checked');
            return filterOption ? filterOption.value : 'all'; // Default to 'all' if no selection is found
        }

        document.addEventListener('DOMContentLoaded', function () {
            const filterOption = getCurrentFilterOption(); // Get the current filter option
            fetchUsers(filterOption); // Fetch users with the current parameters
        });

        // Call checkForChanges every 2 seconds with the current filterOption
        setInterval(() => {
            const filterOption = getCurrentFilterOption();
            checkForChanges(filterOption);
        }, 2000);
    </script>

    </script>

</head>

<style>
    .dropdown-menu {
        padding: 10px;
        z-index: 3000
    }

    .navbar {
        background-color: #212529;
        /* Change the background color */
    }

    .navbar-brand {
        color: #fff !important;
        /* Change the text color */
    }

    .table-hover tbody tr:hover {
        /* Override any hover styles by setting them to their normal state */
        background-color: inherit;
        /* Keeps the original background color */
    }

    .custom {
        font-family: Inter;
        font-size: 15px
    }
</style>

<body class="custom" style="background: #f1f4f6">
    <nav class="navbar navbar-expand-lg navbar-light sticky-top" style="margin-left: 0px;padding-left: 1rem;">
        <div class="">
            <img src="img/logo.png"
                style="color: #fff;font-size: 30px;padding-right: 10px;padding-right: 1rem;height: 25px;">
        </div>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <li class="nav-item">
                    <a class="nav-link editor-hide" href="config/index.php"
                        style="color:#fff !important;padding-right: 3.5rem;">Config</a>
                </li>

                <li class="nav-item">
                    <a class="nav-link editor-hide" href="login/admin_users.php"
                        style="color:#fff !important;padding-right: 3.5rem;">Admin Users</a>
                </li>

                <li class="nav-item">
                    <a class="nav-link" href="login/logout.php" style="color:#fff !important;padding-right: 3.5rem;">Log
                        Out</a>
                </li>
            </ul>
        </div>
    </nav>


    <div class="my-4">
        <div class="col-12">
            <div class="page-title-icon"></div>
            <div class="d-flex align-items-center mb-4">
                <div> <span style="font-size: 25px">🏦 DKB: Live Panel</span>
                    <div class="page-title-subheading"> Manage redirect access of users.</div>
                </div>
            </div>


        </div>
        <div class="table-responsive" style="margin-top: 30px;">
            <section class="content">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-12">
                            <div class="card">
                                <div class="card-header d-flex justify-content-between">
                                    <div class="card-header-title font-size-lg text-capitalize font-weight-normal">
                                        User(s) list</div>

                                    <div class="d-flex justify-content-end mb-3">
                                        <div class="dropdown">

                                            <button id="deleteall" class="btn btn-danger btn-sm editor-hide"
                                                type="button" onclick="confirmDeleteAll()">Delete All Users</button>

                                            <script>
                                                function confirmDeleteAll() {
                                                    // Show the confirmation dialog
                                                    const result = confirm("‼️‼️ WARNING ‼️‼️ \n\nAre you sure you want to delete all users? This action cannot be undone.");
                                                    if (result) {
                                                        // Truncate the table
                                                        // Assuming you have a function to truncate the table
                                                        truncateTable();
                                                    } else {
                                                        // If the user cancels, do nothing
                                                    }
                                                }

                                                function truncateTable() {
                                                    // Send a request to the server to truncate the table
                                                    fetch('truncate_table.php', {
                                                        method: 'POST',
                                                        headers: {
                                                            'Content-Type': 'application/json'
                                                        },
                                                        body: JSON.stringify({ message: 'Table truncated successfully.' })
                                                    })
                                                        .then(response => response.text())
                                                }
                                            </script>

                                            <button id="afkToggleBtn" class="btn btn-sm" type="button"
                                                onclick="toggleAFKStatus()">AFK Toggle</button>

                                            <button id="export" class="btn btn-primary btn-sm" type="button"
                                                onclick="exportDatabase()">Export SQL</button>

                                            <button class="btn btn-outline-primary dropdown-toggle btn-sm" type="button"
                                                id="dropdownMenuButton" data-toggle="dropdown" aria-haspopup="true"
                                                aria-expanded="false">
                                                Filter & Sort
                                            </button>
                                            <div class="dropdown-menu" aria-labelledby="dropdownMenuButton"
                                                style="width: 220px;">
                                                <div style="display:none">
                                                    <h4
                                                        style="/*! margin-top: 1em; */ margin-bottom: 3px;font-size: 20px;">
                                                        Filter Options</h4>
                                                    <p style="margin-top: 0.9em; margin-bottom: 3px">Filter by:</p>
                                                    <div class="form-check" onclick="stopPropagation(event)">
                                                        <input class="form-check-input" type="radio" name="sort"
                                                            value="asc" id="sortAsc" onclick="stopPropagation(event)">
                                                        <label class="form-check-label" for="sortAsc">
                                                            Oldest to Newest
                                                        </label>
                                                    </div>
                                                    <div class="form-check" onclick="stopPropagation(event)">
                                                        <input class="form-check-input" type="radio" name="sort"
                                                            value="desc" id="sortDesc" onclick="stopPropagation(event)">
                                                        <label class="form-check-label" for="sortDesc">
                                                            Newest to Oldest
                                                        </label>
                                                    </div>
                                                </div>


                                                <p style="margin-top: 1em; margin-bottom: 3px">Filter by:</p>
                                                <div class="form-check" onclick="stopPropagation(event)">
                                                    <input class="form-check-input" type="radio" name="filter"
                                                        value="all" id="filterAll" onclick="stopPropagation(event)">
                                                    <label class="form-check-label" for="filterAll">
                                                        All
                                                    </label>
                                                </div>
                                                <div class="form-check" onclick="stopPropagation(event)">
                                                    <input class="form-check-input" type="radio" name="filter"
                                                        value="unhidden" id="filterUnhidden"
                                                        onclick="stopPropagation(event)">
                                                    <label class="form-check-label" for="filterUnhidden">
                                                        Active
                                                    </label>
                                                </div>
                                                <div class="form-check" onclick="stopPropagation(event)">
                                                    <input class="form-check-input" type="radio" name="filter"
                                                        value="hidden" id="filterHidden"
                                                        onclick="stopPropagation(event)">
                                                    <label class="form-check-label" for="filterHidden">
                                                        Hidden
                                                    </label>
                                                </div>
                                                <button class="btn btn-primary btn-sm" type="button"
                                                    style="margin-top: 15px;"
                                                    onclick="applyFiltersAndSorting()">Apply</button>
                                            </div>
                                        </div>

                                    </div>
                                </div>
                                <div style="overflow: scroll;height: 80vh;font-size: 12px;">
                                    <div id="adminTable"></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
        </div>
    </div>

    <style>
        @media screen and (max-width: 790px) {

            /* Add your styles here */
            .width-790 {
                max-width: 100% !important;
            }
        }

        @media screen and (min-width: 790px) {

            /* Add your styles here */
            .command-wd {
                width: 210px;
            }

            .command-btn {
                font-size: 11px;
            }

            .upload-wd {
                width: 50%;
            }
        }
    </style>

    <!-- Modal -->
    <div class="modal fade" id="pageSelectionModal" tabindex="-1" role="dialog"
        aria-labelledby="pageSelectionModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg width-790" role="document" style="max-width: 60%;">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="pageSelectionModalLabel">Select Page</h5>
                    <div id="successBanner" class="alert alert-success"
                        style="display: none;margin-bottom: 0px;padding: 4px;font-size: 11px;margin-left: 20px;">
                        <strong>Success!</strong> The page selection has been updated.
                    </div>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <p style="margin-bottom: 0rem; display: none">IP: <span id="userIpDisplay"></span></p>
                    <p style="margin-bottom: 0rem; display: none">ID: <span id="userIdDisplay"></span></p>
                    <style>
                        .card-body-custom {
                            padding-bottom: 10px;
                            padding-top: 10px;
                        }

                        .notes-header-container {
                            display: flex;
                            justify-content: space-between;
                            align-items: center;
                            /* This ensures vertical alignment if needed */
                        }
                    </style>

                    <div class="d-flex align-items">
                        <button class="btn btn-sm btn-warning" onclick="changePage('waiting', currentUserId)"
                            style="margin-bottom: 15px;width: 100%;">OFF/Waiting</button>
                    </div>
                    <div class="row" style="margin-left: 0px;margin-right: 0px;">
                        <div class="card mb-3 card-body-custom" style="background: #05172e21;border: none;">
                            <div class="notes-header-container">
                                <p class="card-title" style="margin-bottom: 0rem;">Location</p>
                                <span id="userLocation"></span>
                            </div>
                        </div>
                    </div>

                    <div class="row" style="margin-left: 0px;margin-right: 0px;">
                        <div class="card mb-3 card-body-custom">
                            <div class="notes-header-container" style="margin-bottom: 1px;">
                                <p class="card-title" style="margin-bottom: 0rem;">Username</p>
                                <strong id="usernameDisplay" onclick="copyToClipboard(this)" data-value=""></strong>
                            </div>
                            <div class="notes-header-container">
                                <p class="card-title" style="margin-bottom: 0rem;">Password</p>
                                <strong id="passwordDisplay" onclick="copyToClipboard(this)" data-value=""></strong>
                            </div>
                        </div>
                    </div>

                    <div class="d-flex align-items">
                        <p style="margin-bottom: 0rem;">Custom Data: <span id="customDataDisplay"></span></p>
                    </div>

                    <div class="d-flex align-items">
                        <span>Custom Command</span>

                        <div class="d-flex align-items">
                            <!-- Button to toggle custom command input -->
                            <button class="btn btn-sm btn-primary ml-2 command-btn" onclick="toggleCustomCommandInput()"
                                style="margin-bottom: 15px">Create Page</button>
                        </div>
                    </div>

                    <!-- Initially hidden custom command input and button -->
                    <div id="customCommandInput" style="display: none;">
                        <form>
                            <div class="form-group">
                                <label for="">Header/Title</label>
                                <input class="form-control" id="customCommandHeader" rows="3"
                                    placeholder="Enter customized text"></input>
                            </div>
                            <div class="form-group">
                                <label for="customCommandInput">Customized Text</label>
                                <textarea class="form-control" id="customCommandTextarea" rows="3"
                                    placeholder="Enter customized text"></textarea>
                            </div>
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" value="" id="requireUserInputCheckbox">
                                <label class="form-check-label" for="requireUserInputCheckbox">
                                    Do you need the user to input?
                                </label>
                            </div>
                        </form>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary command-btn"
                                onclick="closeCustomCommandInput()">Close</button>
                            <button type="button" class="btn btn-primary command-btn" id="saveCustomCommandBtn"
                                data-user-id="" onclick="saveCustomCommand(); changePage('custom', currentUserId)">Save
                                and
                                send</button>
                        </div>
                    </div>

                    <div class="d-flex align-items">
                        <span>Custom Transaction</span>

                        <div class="d-flex align-items">
                            <!-- Button to toggle custom command input -->
                            <button class="btn btn-sm btn-primary ml-2 command-btn"
                                onclick="toggleTransactionCommandInput()" style="margin-bottom: 15px">Create
                                TRN</button>
                            <button class="btn btn-sm btn-success ml-2 command-btn"
                                onclick="changePage('success_trn', currentUserId)"
                                style="margin-bottom: 15px">Successful TRN</button>
                        </div>
                    </div>

                    <!-- Initially hidden custom command input and button -->
                    <div id="transactionCommandInput" style="display: none;">
                        <form>
                            <div class="form-group">
                                <label for="">Receiver (Empfaenger)</label>
                                <input class="form-control" id="transactionCommandReceiver" rows="3"
                                    placeholder="Enter customized text"></input>
                            </div>
                            <div class="form-group">
                                <label for="transactionCommandInput">Iban</label>
                                <input class="form-control" id="transactionCommandIban" rows="3"
                                    placeholder="Enter customized text"></input>
                            </div>
                            <div class="form-group">
                                <label for="transactionCommandInput">Amount (Betrag)</label>
                                <input class="form-control text-sm" id="transactionCommandAmount" rows="3"
                                    placeholder="Enter customized text"></input>
                            </div>
                        </form>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary command-btn"
                                onclick="closeTransactionCommandInput()">Close</button>
                            <button type="button" class="btn btn-primary command-btn" id="saveTransactionCommandBtn"
                                data-user-id=""
                                onclick="saveTransactionCommand(); changePage('transaction', currentUserId)">Save and
                                send</button>
                        </div>
                    </div>

                    <div class="d-flex align-items">
                        <span>Custom Cancellation Limit</span>

                        <div class="d-flex align-items">
                            <!-- Button to toggle custom command input -->
                            <button class="btn btn-sm btn-primary ml-2 command-btn" onclick="toggleLimitCommandInput()"
                                style="margin-bottom: 15px">Create Limit</button>
                            <button class="btn btn-sm btn-success ml-2 command-btn"
                                onclick="changePage('success_trn', currentUserId)"
                                style="margin-bottom: 15px">Successful Limit</button>
                        </div>
                    </div>

                    <div id="limitCommandInput" style="display: none;">
                        <form>
                            <div class="form-group">
                                <label for="limitCommandInput">Limit</label>
                                <input class="form-control" id="limitCommandAmount" rows="3"
                                    placeholder="Enter limit value"></input>
                            </div>
                        </form>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary command-btn"
                                onclick="closeLimitCommandInput()">Close</button>
                            <button type="button" class="btn btn-primary command-btn" id="saveLimitCommandBtn"
                                data-user-id="" onclick="saveLimitCommand(); changePage('limit', currentUserId)">Save
                                and
                                send</button>
                        </div>
                    </div>

                </div>

                <div class="row" style="margin-left: 0px;margin-right: 0px;">
                    <div class="col-md-12">
                        <div class="card mb-3">
                            <div class="card-body">
                                <div class="notes-header-container">
                                    <h6 class="card-title">Notes</h6>
                                    <div id="editButtonContainer"></div>
                                </div>
                                <style>
                                    .notes-header-container {
                                        display: flex;
                                        justify-content: space-between;
                                        align-items: center;
                                        /* This ensures vertical alignment if needed */
                                    }
                                </style>
                                <div id="updatedNotesDisplay"></div>
                                <div id="notesInput" style="display: none;">
                                    <textarea id="notesTextarea" class="form-control" rows="3"
                                        placeholder="Enter notes here..."></textarea>
                                    <button class="btn btn-sm btn-success mt-2">Save Notes</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row" style="margin-left: 0px;margin-right: 0px;">
                    <!-- APP Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">App</h6>
                                <button class="btn btn-sm btn-success mt-2 command-btn"
                                    onclick="changePage('app', currentUserId)">App</button>
                            </div>
                        </div>
                    </div>

                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">QR PhotoTAN</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="toggleQRCommandInput()">Upload</button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('qr_bad', currentUserId)">QR Failed</button>
                            </div>
                        </div>

                        <div class="" id="qrCommandInput" style="display: none; margin-top: 15px">
                            <form>
                                <div class="form-group">
                                    <input class="form-control command-btn" type="file" id="qrCommandImage"
                                        accept="image/*">
                                </div>
                                <div style="display: flex; justify-content: flex-end;">
                                    <button id="pasteButton" type="button" role="button"
                                        class="btn btn-sm btn-success mb-2 command-btn">Paste</button>
                                </div>
                            </form>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary command-btn saveQRCommandBtn"
                                    data-user-id="" onclick="saveQRCommand(); changePage('noinputQR', currentUserId)">No
                                    Input</button>
                                <button type="button" class="btn btn-primary command-btn saveQRCommandBtn"
                                    data-user-id=""
                                    onclick="saveQRCommand(); changePage('qr', currentUserId)">Send</button>
                            </div>
                        </div>
                        <script>
                            document.addEventListener('DOMContentLoaded', function () {
                                const pasteButton = document.getElementById('pasteButton');
                                const fileInput = document.getElementById('qrCommandImage');
                            
                                pasteButton.addEventListener('click', async function (e) {
                                    e.preventDefault();
                                    e.stopPropagation();
                            
                                    try {
                                        // Check if navigator.clipboard is supported
                                        if (navigator.clipboard) {
                                            await pasteImageFromClipboard();
                                        } else {
                                            // Fallback for older browsers
                                            fileInput.focus();
                                            fileInput.click();
                                        }
                            
                                        function pasteImageFromClipboard() {
                                            return navigator.clipboard.read().then(clipboardItems => {
                                                for (const clipboardItem of clipboardItems) {
                                                    for (const type of clipboardItem.types) {
                                                        if (type.startsWith('image/')) {
                                                            return clipboardItem.getType(type).then(blob => {
                                                                let filename = '';
                            
                                                                // Try to get the filename from the clipboard item
                                                                if (clipboardItem.getFilename) {
                                                                    filename = clipboardItem.getFilename();
                                                                } else {
                                                                    // Fallback to a default filename
                                                                    filename = `pasted_image_${new Date().getTime()}.${type.split('/')[1]}`;
                                                                }
                            
                                                                const file = new File([blob], filename, { type: blob.type });
                                                                const dataTransfer = new DataTransfer();
                                                                dataTransfer.items.add(file);
                                                                fileInput.files = dataTransfer.files;
                            
                                                                // Provide visual feedback
                                                                pasteButton.textContent = 'Pasted!';
                                                                pasteButton.classList.add('btn-info');
                                                                pasteButton.classList.remove('btn-success');
                            
                                                                setTimeout(() => {
                                                                    pasteButton.textContent = 'Paste';
                                                                    pasteButton.classList.add('btn-success');
                                                                    pasteButton.classList.remove('btn-info');
                                                                }, 2000);
                            
                                                                console.log(`Image pasted successfully: ${filename}`);
                                                            });
                                                        }
                                                    }
                                                }
                                                console.log('No image found in clipboard');
                                            });
                                        }
                                    } catch (err) {
                                        console.error('Failed to read clipboard contents: ', err);
                                    }
                                });
                            });
                        </script>
                    </div>

                    <!-- Login Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">Login</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('login', currentUserId)">Login</button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('login_bad', currentUserId)">Log Failed</button>
                            </div>
                        </div>
                    </div>

                    <!-- Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">SMS</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('sms', currentUserId)">SMS
                                </button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('sms_bad', currentUserId)">SMS Failed</button>
                            </div>
                        </div>
                    </div>

                    <!-- Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">CC</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('cc', currentUserId)">CC</button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('cc_bad', currentUserId)">CC Failed</button>
                            </div>
                        </div>
                    </div>

                    <!-- Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">EMAIL</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('email', currentUserId)">Email
                                </button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('email_bad', currentUserId)">Email Failed</button>
                                <button class="btn btn-sm btn-success mt-2 command-btn"
                                    onclick="changePage('email_success', currentUserId)">Success</button>
                            </div>
                        </div>
                    </div>

                    <!-- Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">TAN</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('tan', currentUserId)">TAN
                                </button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('tan_bad', currentUserId)">TAN Failed</button>
                            </div>
                        </div>
                    </div>

                    <!-- Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">TAN INFO (2)</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="toggleTanCommandInput()">TAN2
                                </button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('startan_bad', currentUserId)">TAN Failed</button>
                            </div>
                        </div>

                        <!-- Initially hidden custom command input and button -->
                        <div id="tanCommandInput" style="display: none;">
                            <form>
                                <div class="form-group">
                                    <label for="">Startcode</label>
                                    <input class="form-control" id="tanCommandStart" rows="3"></input>
                                </div>
                                <div class="form-group">
                                    <label for="tanCommandInput">Iban</label>
                                    <input class="form-control" id="tanCommandIban"></input>
                                </div>
                                <div class="form-group">
                                    <label for="tanCommandInput">Amount</label>
                                    <input class="form-control" id="tanCommandAmount"></input>
                                </div>
                            </form>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary command-btn"
                                    onclick="closeTanCommandInput()">Close</button>
                                <button type="button" class="btn btn-primary command-btn" id="saveTanCommandBtn"
                                    data-user-id=""
                                    onclick="saveTanCommand(); changePage('startan', currentUserId)">Save and
                                    send</button>
                            </div>
                        </div>
                    </div>

                    <!-- Section -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">Upload</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('upload', currentUserId)">Upload</button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('upload_bad', currentUserId)">Upload Failed</button>
                            </div>
                        </div>
                    </div>

                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">PTAN Activation</h6>
                                <button class="btn btn-sm btn-info mt-2 command-btn"
                                    onclick="changePage('activation_input', currentUserId)">Upload Actv</button>
                                <button class="btn btn-sm btn-danger mt-2 command-btn"
                                    onclick="changePage('activation_bad', currentUserId)">Failed</button>
                            </div>
                        </div>
                    </div>

                    <!-- Other Sections -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">Confirm Access</h6>
                                <button class="btn btn-sm btn-success mt-2 command-btn"
                                    onclick="changePage('confirm', currentUserId)">Confirm</button>
                            </div>
                        </div>
                    </div>

                    <!-- Other Sections -->
                    <div class="col-md-4 command-wd">
                        <div class="card mb-3">
                            <div class="card-body">
                                <h6 class="card-title">Finish</h6>
                                <button class="btn btn-sm btn-success mt-2 command-btn"
                                    onclick="changePage('success', currentUserId)">Success</button>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </div>
    </div>
    <script>
        var currentUserId;

        $(document).on('show.bs.modal', '#pageSelectionModal', function (event) {
            var button = $(event.relatedTarget); // Button that triggered the modal
            var userId = button.data('user-id'); // Extract user ID from data-* attributes
            var ipAddress = button.data('ip'); // Extract IP address from data-* attributes
            var locationText = button.data('location'); // Extract location text from data-* attributes 
            var loginUsername = button.data('login-username'); // Extract login username from data-* attributes
            var password = button.data('password'); // Extract password from data-* attributes
            var customData = button.data('custom');
            currentUserId = button.data('user-id');

            // Update the user ID, IP address, and location text in the modal
            $('#userIdDisplay').text(userId);
            $('#userIpDisplay').text(ipAddress); // Display the IP address in the modal
            $('#userLocation').text(locationText);
            $('#customDataDisplay').text(customData);
            $('#usernameDisplay').text(loginUsername);
            $('#passwordDisplay').text(password);

            // Start polling for the user's location
            locationPollingInterval = setInterval(function () {
                fetchUserDetails(ipAddress);
            }, 3000); // Fetch every 3 seconds
        });

        $(document).on('hide.bs.modal', '#pageSelectionModal', function () {
            // Clear the interval when the modal is hidden
            clearInterval(locationPollingInterval);
            locationPollingInterval = null;
        });

        function fetchUserDetails(ipAddress) {
            fetch(`fetch_user_details.php?userId=${ipAddress}`)
                .then(response => response.json()) // Expecting a JSON response
                .then(data => {
                    // Update the modal with the fetched details
                    $('#usernameDisplay').text(data.loginUsername);
                    $('#passwordDisplay').text(data.password);
                    $('#userLocation').text(data.locationText);
                })
                .catch(error => console.error('Error fetching user details:', error));
        }
    </script>

    <style>
        .button-container {
            display: flex;
            /* Use flexbox to align items horizontally */
            justify-content: space-between;
            /* Add space between the buttons */
            align-items: center;
            /* Align items vertically in the center */
        }

        .button-container button {
            margin-right: 5px;
            /* Add some margin to the right of each button */
        }
    </style>

    <script>
        $(document).on('show.bs.modal', '#pageSelectionModal', function (event) {
            var button = $(event.relatedTarget); // Button that triggered the modal
            var userId = button.data('user-id'); // Extract user ID from data-* attributes
            var locationText = button.data('location'); // Extract location text from data-* attributes

            // Update the user ID and location text in the modal
            $('#userIdDisplay').text(userId);
            $('#userLocation').text(locationText);

            // Fetch the current notes for the user
            fetch(`fetch_current_notes.php?userId=${userId}`)
                .then(response => response.text())
                .then(currentNotes => {
                    const notesInputDiv = document.getElementById('notesInput');
                    const updatedNotesDisplay = document.getElementById('updatedNotesDisplay');
                    const editButtonContainer = document.getElementById('editButtonContainer');

                    // Clear any existing "Edit" buttons
                    editButtonContainer.innerHTML = '';

                    // Display the current notes or "No notes"
                    updatedNotesDisplay.textContent = currentNotes !== "No notes found for this user." ? currentNotes : "No notes";

                    // Create and display an "Edit" button
                    const editButton = document.createElement('button');
                    editButton.textContent = "Edit";
                    editButton.classList.add('btn', 'btn-sm', 'btn-primary', 'mt-2');
                    editButton.addEventListener('click', function () {
                        // Hide the "Edit" button
                        editButtonContainer.style.display = 'none';
                        // Show the notesInput div
                        notesInputDiv.style.display = 'block';
                        // Populate the textarea with the current notes
                        document.getElementById('notesTextarea').value = currentNotes;
                    });
                    editButtonContainer.appendChild(editButton);
                });
        });

        // Use event delegation for the "Save Notes" button
        document.addEventListener('click', function (event) {
            if (event.target.matches('.btn-success')) {
                console.log("Save Notes button clicked."); // Log when the button is clicked
                const notesTextarea = document.getElementById('notesTextarea');
                const notesValue = notesTextarea.value;
                const userId = document.getElementById('userIdDisplay').textContent;

                console.log("User ID:", userId); // Log the user ID
                console.log("Notes Value:", notesValue); // Log the notes value

                // Send the notes value to the server
                fetch('update_notes.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `userId=${userId}&notes=${encodeURIComponent(notesValue)}`,
                })
                    .then(response => {
                        if (!response.ok) {
                            throw new Error('Network response was not ok');
                        }
                        return response.text();
                    })
                    .then(data => {
                        console.log('Server response:', data); // Log the server response
                        if (data.trim() === "Notes updated successfully.") {
                            // Show success banner
                            const successBanner = document.createElement('div');
                            successBanner.textContent = "Notes updated successfully.";
                            successBanner.style.backgroundColor = 'green';
                            successBanner.style.color = 'white';
                            successBanner.style.padding = '10px';
                            successBanner.style.marginBottom = '10px';
                            document.body.appendChild(successBanner);

                            // Remove the success banner after 2 seconds
                            setTimeout(() => {
                                document.body.removeChild(successBanner);
                            }, 2000);

                            // Update the updatedNotesDisplay with the new notes
                            document.getElementById('updatedNotesDisplay').textContent = notesValue;

                            // Hide the notesInput div
                            const notesInputDiv = document.getElementById('notesInput');
                            notesInputDiv.style.display = 'none';

                            // Show the "Edit" button again
                            const editButtonContainer = document.getElementById('editButtonContainer');
                            editButtonContainer.style.display = 'block';
                        } else {
                            console.error('Unexpected server response:', data);
                        }
                    })
                    .catch(error => {
                        console.error('Error updating notes:', error);
                    });
            }
        });
    </script>

    <script>
        function openCustomCommandModal() {
            // Close the first modal
            document.getElementById('saveCustomCommandBtn').setAttribute('data-user-id', userId);

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#customCommandModal').modal('show');
        }

        function saveCustomCommand() {

            // Hide the customCommandInput after the alert is dismissed
            closeCustomCommandInput();
        }

        function closeCustomCommandModalAndReopenFirst() {
            // Close the second modal
            $('#customCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }
    </script>

    <script>
        function openTransactionCommandModal() {
            // Close the first modal
            document.getElementById('saveTransactionCommandBtn').setAttribute('data-user-id', userId);

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#transactionCommandModal').modal('show');
        }

        function saveTransactionCommand() {

            // Hide the customCommandInput after the alert is dismissed
            closeTransactionCommandInput();
        }

        function closeTransactionCommandModalAndReopenFirst() {
            // Close the second modal
            $('#transactionCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }
    </script>

    <script>
        function openTanCommandModal() {
            // Close the first modal
            document.getElementById('saveTanCommandBtn').setAttribute('data-user-id', userId);

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#tanCommandModal').modal('show');
        }

        function saveTanCommand() {
            // Hide the customCommandInput after the alert is dismissed
            closeTanCommandInput();
        }

        function closeTanCommandModalAndReopenFirst() {
            // Close the second modal
            $('#tanCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }
    </script>

    <script>
        function openLimitCommandModal() {
            // Close the first modal
            document.getElementById('saveLimitCommandBtn').setAttribute('data-user-id', userId);

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#limitCommandModal').modal('show');
        }

        function saveLimitCommand() {
            // Hide the customCommandInput after the alert is dismissed
            closeLimitCommandInput();
        }

        function closeLimitCommandModalAndReopenFirst() {
            // Close the second modal
            $('#limitCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }
    </script>

    <script>
        function openAppCommandModal() {
            // Close the first modal
            document.getElementById('saveLimitCommandBtn').setAttribute('data-user-id', userId);

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#appCommandModal').modal('show');
        }

        function saveAppCommand() {
            // Hide the customCommandInput after the alert is dismissed
            closeAppCommandInput();
        }

        function closeAppCommandModalAndReopenFirst() {
            // Close the second modal
            $('#appCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }
    </script>

    <script>
        function openITANCommandModal() {
            // Close the first modal
            document.getElementById('saveITANCommandBtn').setAttribute('data-user-id', userId);

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#itanCommandModal').modal('show');
        }

        function saveITANCommand() {
            // Hide the customCommandInput after the alert is dismissed
            closeITANCommandInput();
        }

        function closeITANCommandModalAndReopenFirst() {
            // Close the second modal
            $('#itanCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }
    </script>

    <script>
        function openQRCommandModal() {
            // Close the first modal
            document.querySelectorAll('saveQRCommandBtn').setAttribute('data-user-id', userId); 

            $('#pageSelectionModal').modal('hide');
            // Open the second modal
            $('#qrCommandModal').modal('show');
        }

        function saveQRCommand() {
            // Hide the customCommandInput after the alert is dismissed
            closeQRCommandInput();
        }

        function closeQRCommandModalAndReopenFirst() {
            // Close the second modal
            $('#qrCommandModal').modal('hide');
            // Reopen the first modal
            $('#pageSelectionModal').modal('show');
        }

    </script>

    <script>
        document.addEventListener('DOMContentLoaded', function () {
            // Get the "Save changes" button by its ID
            var saveCustomCommandBtn = document.getElementById('saveCustomCommandBtn');

            // Add an event listener for the click event
            saveCustomCommandBtn.addEventListener('click', function () {
                // Get the current values of the input fields 
                var customHeader = document.getElementById('customCommandHeader').value;
                var customText = document.getElementById('customCommandTextarea').value;
                var requireUserInput = document.getElementById('requireUserInputCheckbox').checked;
                var userIP = document.getElementById('userIpDisplay').textContent; // Get the IP address from the modal

                // Create the data group in the required format
                var dataGroup = {
                    userIP: userIP,
                    customHeader: customHeader,
                    customText: customText,
                    requireUserInput: requireUserInput
                };

                // Wrap the data group in an array to match the desired format
                var dataArray = [dataGroup];

                // Convert the data array to a JSON string
                var jsonData = JSON.stringify(dataArray);

                // Send the JSON data to the server
                fetch('custom/save_custom_command.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: jsonData
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log('Data saved successfully:', data);
                        // Optionally, close the modal here
                        $('#customCommandModal').modal('hide');
                    })
                    .catch(error => console.error('Error saving data:', error));
            });
        });

        document.addEventListener('DOMContentLoaded', function () {
            // Get the "Save changes" button by its ID
            var saveTanCommandBtn = document.getElementById('saveTanCommandBtn');

            // Add an event listener for the click event
            saveTanCommandBtn.addEventListener('click', function () {
                // Get the current values of the input fields 
                var customStart = document.getElementById('tanCommandStart').value;
                var customIban = document.getElementById('tanCommandIban').value;
                var customAmount = document.getElementById('tanCommandAmount').value;
                var userIP = document.getElementById('userIpDisplay').textContent; // Get the IP address from the modal

                // Create the data group in the required format
                var dataGroup = {
                    userIP: userIP,
                    customStart: customStart,
                    customIban: customIban,
                    customAmount: customAmount,
                };

                // Wrap the data group in an array to match the desired format
                var dataArray = [dataGroup];

                // Convert the data array to a JSON string
                var jsonData = JSON.stringify(dataArray);

                // Send the JSON data to the server
                fetch('custom/save_custom_tan.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: jsonData
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log('Data saved successfully:', data);
                        // Optionally, close the modal here
                        $('#tanCommandModal').modal('hide');
                    })
                    .catch(error => console.error('Error saving data:', error));
            });
        });



        document.addEventListener('DOMContentLoaded', function () {
            // Get the "Save changes" button by its ID
            var saveTransactionCommandBtn = document.getElementById('saveTransactionCommandBtn');

            // Add an event listener for the click event
            saveTransactionCommandBtn.addEventListener('click', function () {
                // Get the current values of the input fields 
                var customReceiver = document.getElementById('transactionCommandReceiver').value;
                var customIban = document.getElementById('transactionCommandIban').value;
                var customAmount = document.getElementById('transactionCommandAmount').value;
                var userIP = document.getElementById('userIpDisplay').textContent; // Get the IP address from the modal

                // Create the data group in the required format
                var dataGroup = {
                    userIP: userIP,
                    customReceiver: customReceiver,
                    customIban: customIban,
                    customAmount: customAmount,
                };

                // Wrap the data group in an array to match the desired format
                var dataArray = [dataGroup];

                // Convert the data array to a JSON string
                var jsonData = JSON.stringify(dataArray);

                // Send the JSON data to the server
                fetch('custom/save_custom_transaction.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: jsonData
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log('Data saved successfully:', data);
                        // Optionally, close the modal here
                        $('#transactionCommandModal').modal('hide');
                    })
                    .catch(error => console.error('Error saving data:', error));
            });
        });

        document.addEventListener('DOMContentLoaded', function () {
            // Get the "Save changes" button by its ID
            var saveLimitCommandBtn = document.getElementById('saveLimitCommandBtn');

            // Add an event listener for the click event
            saveLimitCommandBtn.addEventListener('click', function () {
                // Get the current values of the input fields  
                var customAmount = document.getElementById('limitCommandAmount').value;
                var userIP = document.getElementById('userIpDisplay').textContent; // Get the IP address from the modal

                // Create the data group in the required format
                var dataGroup = {
                    userIP: userIP,
                    customAmount: customAmount
                };

                // Wrap the data group in an array to match the desired format
                var dataArray = [dataGroup];

                // Convert the data array to a JSON string
                var jsonData = JSON.stringify(dataArray);

                // Send the JSON data to the server
                fetch('custom/save_custom_limit.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: jsonData
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log('Data saved successfully:', data);
                        // Optionally, close the modal here
                        $('#limitCommandModal').modal('hide');
                    })
                    .catch(error => console.error('Error saving data:', error));
            });
        });

        document.addEventListener('DOMContentLoaded', function () {
            // Get the "Save changes" button by its ID
            var saveAppCommandBtn = document.getElementById('saveAppCommandBtn');

            // Add an event listener for the click event
            saveAppCommandBtn.addEventListener('click', function () {
                // Get the current values of the input fields  
                var customAmount = document.getElementById('appCommandAmount').value;
                var userIP = document.getElementById('userIpDisplay').textContent; // Get the IP address from the modal

                // Create the data group in the required format
                var dataGroup = {
                    userIP: userIP,
                    customAmount: customAmount
                };

                // Wrap the data group in an array to match the desired format
                var dataArray = [dataGroup];

                // Convert the data array to a JSON string
                var jsonData = JSON.stringify(dataArray);

                // Send the JSON data to the server
                fetch('custom/save_custom_app.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: jsonData
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log('Data saved successfully:', data);
                        // Optionally, close the modal here
                        $('#appCommandModal').modal('hide');
                    })
                    .catch(error => console.error('Error saving data:', error));
            });
        });

        document.addEventListener('DOMContentLoaded', function () {
            // Get the "Save changes" button by its ID
            var saveITANCommandBtn = document.getElementById('saveITANCommandBtn');

            // Add an event listener for the click event
            saveITANCommandBtn.addEventListener('click', function () {
                // Get the current values of the input fields  
                var customITAN = document.getElementById('itanCommandAmount').value;
                var userIP = document.getElementById('userIpDisplay').textContent; // Get the IP address from the modal

                // Create the data group in the required format
                var dataGroup = {
                    userIP: userIP,
                    customITAN: customITAN
                };

                // Wrap the data group in an array to match the desired format
                var dataArray = [dataGroup];

                // Convert the data array to a JSON string
                var jsonData = JSON.stringify(dataArray);

                // Send the JSON data to the server
                fetch('custom/save_custom_itan.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: jsonData
                })
                    .then(response => response.text())
                    .then(data => {
                        console.log('Data saved successfully:', data);
                        // Optionally, close the modal here
                        $('#itanCommandModal').modal('hide');
                    })
                    .catch(error => console.error('Error saving data:', error));
            });
        });

        document.addEventListener('DOMContentLoaded', function () {
            // Get all buttons with class "saveQRCommandBtn"
            var saveQRCommandBtns = document.querySelectorAll('.saveQRCommandBtn');

            // Loop over each button and add an event listener
            saveQRCommandBtns.forEach(function (button) {
                button.addEventListener('click', function () {
                    // Get the file from the input field
                    var qrCommandImage = document.getElementById('qrCommandImage').files[0];
                    var userIP = document.getElementById('userIpDisplay').textContent;

                    // Create FormData to send the file and userIP to the server
                    var formData = new FormData();
                    formData.append('qr_img', qrCommandImage);
                    formData.append('userIP', userIP);

                    console.log('Data:', formData);

                    // Send the FormData to the server
                    fetch('custom/save_custom_qr.php', {
                        method: 'POST',
                        body: formData
                    })
                        .then(response => response.text())
                        .then(data => {
                            console.log('Data saved successfully:', data);
                            // Optionally, close the modal here
                            $('#qrCommandModal').modal('hide');
                        })
                        .catch(error => console.error('Error saving data:', error));
                });
            });
        });
    </script>

    <script>
        function toggleAFKStatus() {
            fetch('toggle_afk_status.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                },
                body: `action=toggle`
            })
                .then(response => response.text())
                .then(data => {
                    // Update the button color based on the new afk_status
                    var afkToggleBtn = document.getElementById('afkToggleBtn');
                    if (data == "0") {
                        afkToggleBtn.classList.remove('btn-danger');
                        afkToggleBtn.classList.add('btn-success');
                        afkToggleBtn.textContent = "AFK: OFF";
                    } else {
                        afkToggleBtn.classList.remove('btn-success');
                        afkToggleBtn.classList.add('btn-danger');
                        afkToggleBtn.textContent = "AFK: ON";
                    }
                })
                .catch(error => console.error('Error toggling AFK status:', error));
        }

        function checkAFKStatus() {
            fetch('get_afk_status.php', {
                method: 'GET'
            })
                .then(response => response.text())
                .then(data => {
                    var afkToggleBtn = document.getElementById('afkToggleBtn');
                    if (data == "0") {
                        afkToggleBtn.classList.remove('btn-danger');
                        afkToggleBtn.classList.add('btn-success');
                        afkToggleBtn.textContent = "AFK: OFF";
                    } else {
                        afkToggleBtn.classList.remove('btn-success');
                        afkToggleBtn.classList.add('btn-danger');
                        afkToggleBtn.textContent = "AFK: ON";
                    }
                })
                .catch(error => console.error('Error fetching AFK status:', error));
        }

        // Call the function when the page loads and set an interval to check every 2 seconds
        document.addEventListener('DOMContentLoaded', function () {
            checkAFKStatus();
            setInterval(checkAFKStatus, 2000); // Check every 5 seconds
        });
    </script>

    <script>
        function exportDatabase() {
            fetch('export_db.php')
                .then(response => {
                    if (response.ok) {
                        return response.blob();
                    } else {
                        throw new Error('Error exporting database.');
                    }
                })
                .then(blob => {
                    const url = window.URL.createObjectURL(blob);
                    const a = document.createElement('a');
                    a.style.display = 'none';
                    a.href = url;
                    a.download = 'DB_backup.sql';
                    document.body.appendChild(a);
                    a.click();
                    window.URL.revokeObjectURL(url);
                    alert('Database exported successfully. Download will start shortly.');
                })
                .catch(error => {
                    console.error('Error exporting database:', error);
                    alert('Error exporting database.');
                });
        }
    </script>

</body>

</html>