<?php
session_start();
require_once '../db_config.php';

// Check if the form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $username = $_POST["username"];
    $password = $_POST["password"];
    $adminType = $_POST["adminType"]; // Retrieve the selected admin type

    // Prepare and execute SQL query to insert a new admin user
    $sql = "INSERT INTO admin_users (username, password, status) VALUES (?,?,?)"; // Updated to include status
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("sss", $username, $password, $adminType); // Added s for status parameter
    $stmt->execute();

    // Check if the query was successful
    if ($stmt->affected_rows > 0) {
        $success = "Admin user created successfully!";
        header("Location:admin_users.php");
        exit;
    } else {
        $error = "Error creating admin user.";
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Create Admin</title>
    <!-- Bootstrap CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <style>
       .centered-container {
            background-color: #f8f9fa;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }
       .custom-form {
            background-color: #fff;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
            max-width: 500px; /* Adjust the max-width as needed */
            width: 100%;
        }
       .btn-fill-width {
            width: 100%;
        }
        .inputcustom {
            width: 1em;
            height: 1em;
            margin-top: .25em;
            vertical-align: top;
            background-color: #fff;
            background-repeat: no-repeat;
            background-position: center;
            background-size: contain;
            border: 1px solid rgba(0,0,0,.25); 
        }
    </style>
</head>

<body>
    <div class="centered-container">
        <div class="custom-form">
            <h2 class="mb-4 text-left">Create Admin</h2>
            <?php if (isset($success)): ?>
                <div class="alert alert-success" role="alert">
                    <?php echo $success; ?>
                </div>
            <?php endif; ?> 
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>
            <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>">
                <div class="form-group">
                    <label for="username">Username:</label>
                    <input type="text" class="form-control" id="username" name="username" required>
                </div>
                <div class="form-group">
                    <label for="password">Password:</label>
                    <input type="password" class="form-control" id="password" name="password" required>
                </div>
                <div class="form-group">
                    <label for="adminType">Admin Type:</label>
                    <select class="form-control" id="adminType" name="adminType" required>
                        <option value="">Select Admin Type</option>
                        <option value="super_admin">Super Admin</option>
                        <option value="editor">Editor</option>
                    </select>
                </div>
                <button type="submit" class="btn btn-success btn-fill-width">Create Admin</button>
                <a href="../index.php" class="btn btn-fill-width" style="margin-top: 15px; color: #007bff !important;">Go Back</a>
            </form>
        </div>
    </div>

    <!-- Include jQuery first -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

    <!-- Then include Bootstrap's JavaScript -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>