<?php
// Include database configuration
require_once '../db_config.php';

// Set header to indicate JSON response
header('Content-Type: application/json');

// Initialize response array
$response = array(
    'success' => false,
    'message' => 'An unknown error occurred.'
);

// Sanitize and validate input data
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $userId = intval($_POST['userId']);
    $username = filter_var($_POST['username'], FILTER_SANITIZE_STRING);
    $password = filter_var($_POST['password'], FILTER_SANITIZE_STRING);
    $status = filter_var($_POST['status'], FILTER_SANITIZE_STRING);


    // Check connection
    if ($conn->connect_error) {
        die(json_encode(array('success' => false, 'message' => "Connection failed: ". $conn->connect_error)));
    }

    // Prepare and bind parameters
    $sql = "UPDATE admin_users SET username=?, password=?, status=? WHERE id=?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("sssi", $username, $password, $status, $userId);

    // Execute the statement
    if ($stmt->execute()) {
        // Check if any rows were affected
        if ($stmt->affected_rows > 0) {
            $response['success'] = true;
            $response['message'] = "User updated successfully. Rows affected: ". $stmt->affected_rows;
        } else {
            $response['message'] = "No rows were updated. Please verify the user ID and data.";
        }
    } else {
        $response['message'] = "Failed to execute statement: ". $stmt->error;
    }

    // Close statement and connection
    $stmt->close();
    $conn->close();

    // Send JSON response
    echo json_encode($response);
} else {
    echo json_encode(array('success' => false, 'message' => "Invalid request method."));
}
?>